Display

Trait Display 

1.36.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.100.0 · Source

impl Display for !

1.26.0 · Source

impl Display for AccessError

1.4.0 · Source

impl Display for AddrParseError

Source

impl Display for rquickjs::alloc::alloc::AllocError

Source

impl Display for allocator_api2::stable::alloc::AllocError

1.0.0 · Source

impl Display for Arguments<'_>

Source

impl Display for AsciiChar

1.65.0 · Source

impl Display for Backtrace

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError

Source

impl Display for ByteStr

Source

impl Display for ByteString

1.34.0 · Source

impl Display for CharTryFromError

1.9.0 · Source

impl Display for DecodeUtf16Error

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>

Source

impl Display for relative_path::Display<'_>

1.0.0 · Source

impl Display for rquickjs::alloc::io::Error

1.0.0 · Source

impl Display for rquickjs::alloc::fmt::Error

Source

impl Display for rquickjs::Error

Source

impl Display for dlopen2::err::Error

1.60.0 · Source

impl Display for ErrorKind

1.20.0 · Source

impl Display for core::char::EscapeDebug

1.39.0 · Source

impl Display for core::ascii::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeUnicode

Source

impl Display for Exception<'_>

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError

Source

impl Display for FixedOffset

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.17.0 · Source

impl Display for FromBytesWithNulError

Source

impl Display for FromPathError

Available on crate feature std only.
1.0.0 · Source

impl Display for FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.58.0 · Source

impl Display for FromVecWithNulError

1.86.0 · Source

impl Display for rquickjs::alloc::slice::GetDisjointMutError

Source

impl Display for indexmap::GetDisjointMutError

Source

impl Display for GetTimezoneError

1.7.0 · Source

impl Display for IntoStringError

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

1.0.0 · Source

impl Display for JoinPathsError

1.28.0 · Source

impl Display for LayoutError

1.26.0 · Source

impl Display for Location<'_>

Source

impl Display for NaiveDate

The Display output of the naive date d is the same as d.format("%Y-%m-%d").

The string printed can be readily parsed via the parse method on str.

Example

use chrono::NaiveDate;

assert_eq!(format!("{}", NaiveDate::from_ymd_opt(2015, 9, 5).unwrap()), "2015-09-05");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(0, 1, 1).unwrap()), "0000-01-01");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(9999, 12, 31).unwrap()), "9999-12-31");

ISO 8601 requires an explicit sign for years before 1 BCE or after 9999 CE.

assert_eq!(format!("{}", NaiveDate::from_ymd_opt(-1, 1, 1).unwrap()), "-0001-01-01");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(10000, 12, 31).unwrap()), "+10000-12-31");
Source

impl Display for NaiveDateTime

The Display output of the naive date and time dt is the same as dt.format("%Y-%m-%d %H:%M:%S%.f").

It should be noted that, for leap seconds not on the minute boundary, it may print a representation not distinguishable from non-leap seconds. This doesn’t matter in practice, since such leap seconds never happened. (By the time of the first leap second on 1972-06-30, every time zone offset around the world has standardized to the 5-minute alignment.)

Example

use chrono::NaiveDate;

let dt = NaiveDate::from_ymd_opt(2016, 11, 15).unwrap().and_hms_opt(7, 39, 24).unwrap();
assert_eq!(format!("{}", dt), "2016-11-15 07:39:24");

Leap seconds may also be used.

let dt =
    NaiveDate::from_ymd_opt(2015, 6, 30).unwrap().and_hms_milli_opt(23, 59, 59, 1_500).unwrap();
assert_eq!(format!("{}", dt), "2015-06-30 23:59:60.500");
Source

impl Display for NaiveTime

The Display output of the naive time t is the same as t.format("%H:%M:%S%.f").

The string printed can be readily parsed via the parse method on str.

It should be noted that, for leap seconds not on the minute boundary, it may print a representation not distinguishable from non-leap seconds. This doesn’t matter in practice, since such leap seconds never happened. (By the time of the first leap second on 1972-06-30, every time zone offset around the world has standardized to the 5-minute alignment.)

Example

use chrono::NaiveTime;

assert_eq!(format!("{}", NaiveTime::from_hms_opt(23, 56, 4).unwrap()), "23:56:04");
assert_eq!(
    format!("{}", NaiveTime::from_hms_milli_opt(23, 56, 4, 12).unwrap()),
    "23:56:04.012"
);
assert_eq!(
    format!("{}", NaiveTime::from_hms_micro_opt(23, 56, 4, 1234).unwrap()),
    "23:56:04.001234"
);
assert_eq!(
    format!("{}", NaiveTime::from_hms_nano_opt(23, 56, 4, 123456).unwrap()),
    "23:56:04.000123456"
);

Leap seconds may also be used.

assert_eq!(
    format!("{}", NaiveTime::from_hms_milli_opt(6, 59, 59, 1_500).unwrap()),
    "06:59:60.500"
);
Source

impl Display for NormalizeError

1.0.0 · Source

impl Display for NulError

Source

impl Display for OutOfRange

Source

impl Display for OutOfRangeError

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

1.0.0 · Source

impl Display for ParseBoolError

1.20.0 · Source

impl Display for ParseCharError

Source

impl Display for ParseError

1.0.0 · Source

impl Display for core::num::float_parse::ParseFloatError

Source

impl Display for num_traits::ParseFloatError

1.0.0 · Source

impl Display for ParseIntError

Source

impl Display for ParseMonthError

Source

impl Display for ParseWeekdayError

1.0.0 · Source

impl Display for RecvError

1.15.0 · Source

impl Display for std::sync::mpsc::RecvTimeoutError

Source

impl Display for RelativePath

Source

impl Display for RelativePathBuf

Source

impl Display for RelativeToError

Source

impl Display for RoundingError

1.0.0 · Source

impl Display for SocketAddr

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6

1.0.0 · Source

impl Display for String

1.7.0 · Source

impl Display for StripPrefixError

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for TimeDelta

Source

impl Display for ToCasefold

1.16.0 · Source

impl Display for ToLowercase

Source

impl Display for ToTitlecase

1.16.0 · Source

impl Display for ToUppercase

1.59.0 · Source

impl Display for TryFromCharError

1.66.0 · Source

impl Display for TryFromFloatSecsError

1.34.0 · Source

impl Display for TryFromIntError

1.35.0 · Source

impl Display for TryFromSliceError

1.89.0 · Source

impl Display for std::fs::TryLockError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError

1.57.0 · Source

impl Display for rquickjs::alloc::collections::TryReserveError

Source

impl Display for indexmap::TryReserveError

Source

impl Display for hashbrown::TryReserveError

Source

impl Display for allocator_api2::stable::raw_vec::TryReserveError

Source

impl Display for Type

Source

impl Display for UnorderedKeyError

Source

impl Display for Utc

1.0.0 · Source

impl Display for Utf8Error

1.0.0 · Source

impl Display for VarError

Source

impl Display for Weekday

Source

impl Display for WeekdaySet

Print the collection as a slice-like list of weekdays.

Example

use chrono::Weekday::*;
assert_eq!("[]", WeekdaySet::EMPTY.to_string());
assert_eq!("[Mon]", WeekdaySet::single(Mon).to_string());
assert_eq!("[Mon, Fri, Sun]", WeekdaySet::from_array([Mon, Fri, Sun]).to_string());
Source

impl Display for WouldBlock

1.56.0 · Source

impl Display for WriterPanicked

1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

1.0.0 · Source

impl Display for f16

1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

1.0.0 · Source

impl Display for isize

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize

Source

impl<'a, I, B> Display for DelayedFormat<I>
where I: Iterator<Item = B> + Clone, B: Borrow<Item<'a>>,

Available on crate feature alloc only.
1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

1.34.0 · Source

impl<'a> Display for rquickjs::alloc::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for rquickjs::alloc::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for rquickjs::alloc::str::EscapeUnicode<'a>

Source

impl<'js> Display for CaughtError<'js>

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,

Source

impl<E> Display for Report<E>
where E: Error,

1.93.0 · Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

Source

impl<K, V, S, A> Display for OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<L, R> Display for Either<L, R>
where L: Display, R: Display,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for rquickjs::alloc::boxed::Box<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for allocator_api2::stable::boxed::Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for async_lock::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for MutexGuardArc<T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for NonZero<T>

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for async_lock::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for RwLockReadGuardArc<T>
where T: Display,

Source

impl<T> Display for RwLockUpgradableReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for RwLockUpgradableReadGuardArc<T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for async_lock::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for RwLockWriteGuardArc<T>
where T: Display + ?Sized,

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.0.0 · Source

impl<T> Display for SendError<T>

Source

impl<T> Display for SendTimeoutError<T>

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

Source

impl<T> Display for std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Display for TrySendError<T>

Source

impl<T> Display for UserDataError<T>

1.10.0 · Source

impl<T> Display for Wrapping<T>
where T: Display,

Source

impl<Tz> Display for Date<Tz>
where Tz: TimeZone, <Tz as TimeZone>::Offset: Display,

Source

impl<Tz> Display for DateTime<Tz>
where Tz: TimeZone, <Tz as TimeZone>::Offset: Display,

1.0.0 · Source

impl<W> Display for IntoInnerError<W>