pub type PhfBundleData<D> = &'static Map<&'static str, D>;Available on crate features
loader and phf only.Expand description
The alias for compiled modules represented as a perfect hash maps
The key is a module name and the value is a module data.